==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QVideoEncoderSettingsControl_shell.h <==
#ifndef QVIDEOENCODERSETTINGSCONTROL_SHELL_H
#define QVIDEOENCODERSETTINGSCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qvideoencodersettingscontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmediaencodersettings.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QVideoEncoderSettingsControl_shell : public QVideoEncoderSettingsControl, public QtJambiShellInterface
{
public:
    QVideoEncoderSettingsControl_shell(QObject* parent0 = nullptr);
    ~QVideoEncoderSettingsControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setVideoSettings(const QVideoEncoderSettings& settings0) override;
    QList<qreal> supportedFrameRates(const QVideoEncoderSettings& settings0, bool* continuous1) const override;
    QList<QSize> supportedResolutions(const QVideoEncoderSettings& settings0, bool* continuous1) const override;
    QStringList supportedVideoCodecs() const override;
    void timerEvent(QTimerEvent* event0) override;
    QString videoCodecDescription(const QString& codec0) const override;
    QVideoEncoderSettings videoSettings() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVideoEncoderSettingsControl_access : public QVideoEncoderSettingsControl
{
    void __qt_setVideoSettings_cref_QVideoEncoderSettings(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0);
    jobject __qt_supportedFrameRates_cref_QVideoEncoderSettings_bool_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0) const;
    jobject __qt_supportedResolutions_cref_QVideoEncoderSettings_bool_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0) const;
    jobject __qt_supportedVideoCodecs(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_videoCodecDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring codec0) const;
    jobject __qt_videoSettings(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QVIDEOENCODERSETTINGSCONTROL_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QVideoEncoderSettingsControl_shell.h <==
#ifndef QVIDEOENCODERSETTINGSCONTROL_SHELL_H
#define QVIDEOENCODERSETTINGSCONTROL_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qvideoencodersettingscontrol.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmediaencodersettings.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QVideoEncoderSettingsControl_shell : public QVideoEncoderSettingsControl, public QtJambiShellInterface
{
public:
    QVideoEncoderSettingsControl_shell(QObject* parent0 = nullptr);
    ~QVideoEncoderSettingsControl_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void setVideoSettings(const QVideoEncoderSettings& settings0) override;
    QList<qreal> supportedFrameRates(const QVideoEncoderSettings& settings0, bool* continuous1) const override;
    QList<QSize> supportedResolutions(const QVideoEncoderSettings& settings0, bool* continuous1) const override;
    QStringList supportedVideoCodecs() const override;
    void timerEvent(QTimerEvent* event0) override;
    QString videoCodecDescription(const QString& codec0) const override;
    QVideoEncoderSettings videoSettings() const override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QVideoEncoderSettingsControl_access : public QVideoEncoderSettingsControl
{
    void __qt_setVideoSettings_cref_QVideoEncoderSettings(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0);
    jobject __qt_supportedFrameRates_cref_QVideoEncoderSettings_bool_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0) const;
    jobject __qt_supportedResolutions_cref_QVideoEncoderSettings_bool_ptr_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID settings0) const;
    jobject __qt_supportedVideoCodecs_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jstring __qt_videoCodecDescription_cref_QString_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring codec0) const;
    jobject __qt_videoSettings_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
};

#endif // QVIDEOENCODERSETTINGSCONTROL_SHELL_H
